A simple web server that can be bound to either the EthernetInterface or the WiflyInterface.

Dependents:   Smart-WiFly-WebServer WattEye X10Svr SSDP_Server

Revision:
4:f34642902056
Parent:
3:17928786bdb5
Child:
5:c9b27e718054
--- a/SW_HTTPServer.h	Mon Jun 24 20:02:01 2013 +0000
+++ b/SW_HTTPServer.h	Tue Jun 25 16:37:06 2013 +0000
@@ -395,9 +395,9 @@
     *
     * @param str is the string to write the address into, which should be at
     *        least as large as "192.168.100.203" (16-bytes).
     * @param size of the str buffer must be >=16, so it will not buffer overrun.
     */
-    void GetRemoteAddr(char * str, int size);
+    void GetRemoteAddr(char * str, int strSize);
 
     /** 
     * This is used to force a connection to close
@@ -524,3 +524,4 @@
     char HexPairToChar(char * p);
 };
 #endif //SW_HTTPSERVER_H
+
@@ -395,9 +395,9 @@
     * @param str is the string to write the address into, which should be at
     *        least as large as "192.168.100.203" (16-bytes).
-    * @param size of the str buffer must be >=16, so it will not buffer overrun.
+    * @param strSize of the str buffer must be >=16, so it will not buffer overrun.
     */